@@ -51,7 +51,7 @@ setValidity("DESeqDataSet", function(object) {
       message("  Note: levels of factors in the design contain characters other than
   letters, numbers, '_' and '.'. It is recommended (but not required) to use
   only letters, numbers, and delimiters '_' or '.', as these are safe characters
-  for column names in R. [This is a message, not an warning or error]")
+  for column names in R. [This is a message, not a warning or an error]")
     }
   } else if (is(design, "matrix")) {
     # TODO add some more tests for if 'design' is matrix
@@ -338,6 +338,14 @@ DESeqDataSetFromMatrix <- function( countData, colData, design, tidy=FALSE, igno
   # check that these agree in number
   stopifnot(ncol(countData) == nrow(colData))
 
+  if (is(countData, "data.frame")) {
+    if (any(sapply(countData, is, "factor"))) {
+      warning("\n\n  'countData' is a data.frame with one or more factor columns.
+  Be aware that converting directly to numeric can lead to errors.
+  Provide matrices of integers to avoid this error.")
+    }
+  }
+  
   # we expect a matrix of counts, which are non-negative integers
   countData <- as.matrix( countData )
 
